@@ -237,6 +237,9 @@ class FireWork(FWSerializable):
         return FireWork(tasks, m_dict['spec'], name, launches, archived_launches,
                         state, created_on, fw_id)
 
+    def __str__(self):
+        return 'FireWork object: (id: %i , name: %s)' % (self.fw_id, self.fw_name)
+
 
 class Launch(FWSerializable, object):
     """
@@ -815,4 +818,7 @@ class Workflow(FWSerializable):
 
     @classmethod
     def from_FireWork(cls, fw, name=None, metadata=None):
-        return Workflow([fw], None, name=name, metadata=metadata)
\ No newline at end of file
+        return Workflow([fw], None, name=name, metadata=metadata)
+
+    def __str__(self):
+        return 'Workflow object: (fw_ids: {} , name: {})'.format(self.id_fw.keys(), self.name)
\ No newline at end of file
