@@ -2,6 +2,7 @@
 
 import logging
 import datetime
+import string
 import sys
 import os
 import traceback
@@ -121,4 +122,10 @@ def get_my_ip():
 
 
 def get_my_host():
-    return socket.gethostname()
\ No newline at end of file
+    return socket.gethostname()
+
+
+def get_slug(m_str):
+    valid_chars = "-_.() %s%s" % (string.ascii_letters, string.digits)
+    m_str = ''.join(c for c in m_str if c in valid_chars)
+    return m_str.replace(' ', '_')
\ No newline at end of file
